Learn R Programming

arrayhelpers (version 1.1-2)

array2vec: Converting array and vector Indices Calculate the vector index from array indices, and vice versa.

Description

arrays are numerics with a dim attribute and are stored with the first index moving fastest (i.e. by column). They can be indexed both ways.

Usage

array2vec(iarr, dim)

vec2array(ivec, dim)

Value

array2vec returns a scalar, vec2array a

matrix.

Arguments

iarr

vector with the indices into the array dimensions

dim

vector with the array dimensions, as returned by dim (x)

ivec

scalar with the index into the vector

Author

C. Beleites

See Also

see Extract on the difference of indexing an array with a vector or a matrix.

Examples

Run this code

arr <- array (rnorm (24), dim = 2 : 4)
arr

v <- matrix(c(2, 2, 2), nrow = 1)
i <- array2vec (v, dim = dim (arr))
i
arr[v]
arr[i]

arr[c(2, 2, 2)] ## indexing with a vector
arr[2]

 
i <- 14
v <- vec2array (i, dim = dim (arr))
v
arr [v]
arr [i]

Run the code above in your browser using DataLab