Learn R Programming

arrayhelpers (version 1.1-2)

groupsum: Extension of rowsum

Description

groupsum extends rowsum: it allows group to be an array of the same shape as x.

Usage

groupsum(
  x,
  group = NULL,
  dim = 1L,
  reorder = TRUE,
  na.rm = FALSE,
  ...,
  drop = !is.array(x)
)

Value

like rowsum, but further dimensions of the array are preserved.

Arguments

x

array to be rowsummed

group

grouping variable (integer or factor) indicating groups of samples.

dim

along which dimension should the group sums be taken? (default: rows)

reorder

should the groups be ordered? see rowsum

na.rm

shoud NAs be removed?

...

ignored

drop

should 1d arrays drop to vectors?

Author

Claudia Beleites

See Also