rowsumgroupsum extends rowsum: it allows group to be an array of the same shape
as x.
groupsum(
x,
group = NULL,
dim = 1L,
reorder = TRUE,
na.rm = FALSE,
...,
drop = !is.array(x)
)like rowsum, but further dimensions of the array are preserved.
array to be rowsummed
grouping variable (integer or factor) indicating groups of samples.
along which dimension should the group sums be taken? (default: rows)
should the groups be ordered? see rowsum
shoud NAs be removed?
ignored
should 1d arrays drop to vectors?
Claudia Beleites